@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@
 from __future__ import annotations
 
 import abc
+from collections.abc import Sequence
 import dataclasses
 import functools
 import inspect
@@ -35,6 +36,7 @@ from tensorflow_datasets.core import dataset_metadata
 from tensorflow_datasets.core import decode
 from tensorflow_datasets.core import download
 from tensorflow_datasets.core import file_adapters
+from tensorflow_datasets.core import lazy_imports_lib
 from tensorflow_datasets.core import logging as tfds_logging
 from tensorflow_datasets.core import naming
 from tensorflow_datasets.core import reader as reader_lib
@@ -44,6 +46,7 @@ from tensorflow_datasets.core import splits as splits_lib
 from tensorflow_datasets.core import tf_compat
 from tensorflow_datasets.core import units
 from tensorflow_datasets.core import utils
+from tensorflow_datasets.core.data_sources import array_record
 from tensorflow_datasets.core.proto import dataset_info_pb2
 from tensorflow_datasets.core.utils import file_utils
 from tensorflow_datasets.core.utils import gcs_utils
@@ -54,8 +57,11 @@ from tensorflow_datasets.core.utils.lazy_imports_utils import tensorflow as tf
 import termcolor
 
 if typing.TYPE_CHECKING:
+  import apache_beam as beam
   from apache_beam.runners import runner
+  from array_record.python import array_record_data_source
 
+ListOrTreeOrElem = type_utils.ListOrTreeOrElem
 Tree = type_utils.Tree
 TreeDict = type_utils.TreeDict
 VersionOrStr = Union[utils.Version, str]
@@ -252,7 +258,7 @@ class DatasetBuilder(registered.RegisteredDataset):
     self._version = self._pick_version(version)
     # Compute the base directory (for download) and dataset/version directory.
     self._data_dir_root, self._data_dir = self._build_data_dir(data_dir)
-    if tf.io.gfile.exists(self._data_dir):
+    if self.data_path.exists():
       self.info.read_from_directory(self._data_dir)
     else:  # Use the code version (do not restore data)
       self.info.initialize_from_bucket()
@@ -303,18 +309,18 @@ class DatasetBuilder(registered.RegisteredDataset):
   def __setstate__(self, state):
     self.__init__(**state)
 
-  @utils.memoized_property
+  @functools.cached_property
   def canonical_version(self) -> utils.Version:
     return cannonical_version_for_config(self, self._builder_config)
 
-  @utils.memoized_property
+  @functools.cached_property
   def supported_versions(self):
     if self._builder_config and self._builder_config.supported_versions:
       return self._builder_config.supported_versions
     else:
       return self.SUPPORTED_VERSIONS
 
-  @utils.memoized_property
+  @functools.cached_property
   def versions(self) -> List[utils.Version]:
     """Versions (canonical + availables), in preference order."""
     return [
@@ -485,15 +491,15 @@ class DatasetBuilder(registered.RegisteredDataset):
   def download_and_prepare(
       self,
       *,
-      download_dir: Optional[str] = None,
+      download_dir: Optional[epath.PathLike] = None,
       download_config: Optional[download.DownloadConfig] = None,
-      file_format: Union[None, str, file_adapters.FileFormat] = None,
+      file_format: Optional[Union[str, file_adapters.FileFormat]] = None,
   ) -> None:
     """Downloads and prepares dataset for reading.
 
     Args:
-      download_dir: `str`, directory where downloaded files are stored. Defaults
-        to "~/tensorflow-datasets/downloads".
+      download_dir: directory where downloaded files are stored. Defaults to
+        "~/tensorflow-datasets/downloads".
       download_config: `tfds.download.DownloadConfig`, further configuration for
         downloading and preparing dataset.
       file_format: optional `str` or `file_adapters.FileFormat`, format of the
@@ -505,7 +511,8 @@ class DatasetBuilder(registered.RegisteredDataset):
     """
 
     download_config = download_config or download.DownloadConfig()
-    data_exists = tf.io.gfile.exists(self._data_dir)
+    data_path = self.data_path
+    data_exists = data_path.exists()
     if data_exists and download_config.download_mode == REUSE_DATASET_IF_EXISTS:
       logging.info("Reusing dataset %s (%s)", self.name, self._data_dir)
       return
@@ -513,8 +520,8 @@ class DatasetBuilder(registered.RegisteredDataset):
       logging.info(
           "Deleting pre-existing dataset %s (%s)", self.name, self._data_dir
       )
-      epath.Path(self._data_dir).rmtree()  # Delete pre-existing data.
-      data_exists = tf.io.gfile.exists(self._data_dir)
+      data_path.rmtree()  # Delete pre-existing data.
+      data_exists = data_path.exists()
 
     if self.version.tfds_version_to_prepare:
       available_to_prepare = ", ".join(
@@ -642,7 +649,7 @@ class DatasetBuilder(registered.RegisteredDataset):
 
     # Clean up incomplete files from preempted workers.
     deleted_incomplete_files = []
-    for f in self.data_path.iterdir():
+    for f in self.data_path.glob(f"*{constants.INCOMPLETE_SUFFIX}*"):
       if utils.is_incomplete_file(f):
         deleted_incomplete_files.append(os.fspath(f))
         f.unlink()
@@ -655,6 +662,50 @@ class DatasetBuilder(registered.RegisteredDataset):
 
     self._log_download_done()
 
+  @tfds_logging.as_data_source()
+  def as_data_source(
+      self,
+      split: Optional[Tree[splits_lib.SplitArg]] = None,
+      *,
+      decoders: Optional[TreeDict[decode.partial_decode.DecoderArg]] = None,
+  ) -> ListOrTreeOrElem[Sequence[Any]]:
+    """Constructs an `ArrayRecordDataSource`.
+
+    Args:
+      split: Which split of the data to load (e.g. `'train'`, `'test'`,
+        `['train', 'test']`, `'train[80%:]'`,...). See our [split API
+        guide](https://www.tensorflow.org/datasets/splits). If `None`, will
+        return all splits in a `Dict[Split, Sequence]`.
+      decoders: Nested dict of `Decoder` objects which allow to customize the
+        decoding. The structure should match the feature structure, but only
+        customized feature keys need to be present. See [the
+        guide](https://github.com/tensorflow/datasets/blob/master/docs/decode.md)
+        for more info.
+
+    Returns:
+      `Sequence` if `split`,
+      `dict<key: tfds.Split, value: Sequence>` otherwise.
+
+    Raises:
+      NotImplementedError if the data was not generated using ArrayRecords.
+    """
+    # By default, return all splits
+    if split is None:
+      split = {s: s for s in self.info.splits}
+
+    # Create a dataset for each of the given splits
+    def build_single_data_source(
+        split: str,
+    ) -> Sequence[Any]:
+      return array_record.ArrayRecordDataSource(
+          self.info,
+          split=split,
+          decoders=decoders,
+      )
+
+    all_ds = tree_utils.map_structure(build_single_data_source, split)
+    return all_ds
+
   @tfds_logging.as_dataset()
   def as_dataset(
       self,
@@ -737,13 +788,13 @@ class DatasetBuilder(registered.RegisteredDataset):
 
     Returns:
       `tf.data.Dataset`, or if `split=None`, `dict<key: tfds.Split, value:
-      tfds.data.Dataset>`.
+      tf.data.Dataset>`.
 
       If `batch_size` is -1, will return feature dictionaries containing
       the entire dataset in `tf.Tensor`s instead of a `tf.data.Dataset`.
     """
     # pylint: enable=line-too-long
-    if not tf.io.gfile.exists(self._data_dir):
+    if not epath.Path(self._data_dir).exists():
       raise AssertionError(
           "Dataset %s: could not find data in %s. Please make sure to call "
           "dataset_builder.download_and_prepare(), or pass download=True to "
@@ -914,7 +965,7 @@ class DatasetBuilder(registered.RegisteredDataset):
       # List all existing versions
       full_builder_dir = os.path.join(data_dir_root, builder_dir)
       data_dir_versions = set(utils.version.list_all_versions(full_builder_dir))
-      # Check for existance of the requested version
+      # Check for existence of the requested version
       if self.version in data_dir_versions:
         requested_version_dirs[data_dir_root] = os.path.join(
             data_dir_root, version_dir
@@ -1208,7 +1259,7 @@ class FileReaderBuilder(DatasetBuilder):
     super().__init__(**kwargs)
     self.info.set_file_format(file_format)
 
-  @utils.memoized_property
+  @functools.cached_property
   def _example_specs(self):
     return self.info.features.get_serialized_info()
 
@@ -1338,7 +1389,7 @@ class GeneratorBasedBuilder(FileReaderBuilder):
     ```
 
     * A `beam.PCollection`: This should only be used if you need to share some
-    distributed processing accross splits. In this case, you can use the
+    distributed processing across splits. In this case, you can use the
     following pattern:
 
     ```python
@@ -1489,6 +1540,33 @@ class GeneratorBasedBuilder(FileReaderBuilder):
     split_dict = splits_lib.SplitDict(split_infos)
     self.info.set_splits(split_dict)
 
+  def read_tfrecord_beam(
+      self,
+      file_pattern: str,
+      /,
+      **kwargs,
+  ) -> "beam.PTransform":
+    """Returns a PTransform reading the TFRecords and records it in the dataset lineage.
+
+    This function records the lineage in the DatasetInfo and then invokes
+    `beam.io.ReadFromTFRecord`. The kwargs should contain any other parameters
+    for `beam.io.ReadFromTFRecord`. See
+    https://beam.apache.org/releases/pydoc/2.6.0/apache_beam.io.tfrecordio.html#apache_beam.io.tfrecordio.ReadFromTFRecord.
+
+    Arguments:
+      file_pattern: A file glob pattern to read TFRecords from.
+      **kwargs: the other parameters for `beam.io.ReadFromTFRecord`.
+
+    Returns:
+      a Beam PTransform that reads the given TFRecord files.
+    """
+    self.info.add_file_data_source_access(file_pattern)
+    beam = lazy_imports_lib.lazy_imports.apache_beam
+    return beam.io.ReadFromTFRecord(
+        file_pattern=file_pattern,
+        **kwargs,
+    )
+
 
 @utils.docs.deprecated
 class BeamBasedBuilder(GeneratorBasedBuilder):
@@ -1557,7 +1635,7 @@ def _save_default_config_name(
   # Note:
   # * Save inside a dir to support some replicated filesystem
   # * Write inside a `.incomplete` file and rename to avoid multiple configs
-  #   writing concurently the same file
+  #   writing concurrently the same file
   # * Config file is overwritten each time a config is generated. If the
   #   default config is changed, this will be updated.
   config_path = config_dir / "metadata.json"
