@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,6 +38,7 @@ from tensorflow_datasets.core import load
 from tensorflow_datasets.core import naming
 from tensorflow_datasets.core import splits as splits_lib
 from tensorflow_datasets.core import utils
+from tensorflow_datasets.core.data_sources import array_record
 from tensorflow_datasets.core.utils import file_utils
 from tensorflow_datasets.core.utils import read_config as read_config_lib
 from tensorflow_datasets.testing.dummy_config_based_datasets.dummy_ds_1 import dummy_ds_1_dataset_builder
@@ -487,6 +488,29 @@ class DatasetBuilderTest(parameterized.TestCase, testing.TestCase):
     )
     self.assertEqual(reference, expected_reference)
 
+  def test_load_as_data_source(self):
+    data_dir = self.get_temp_dir()
+    builder = DummyDatasetWithConfigs(
+        data_dir=data_dir,
+        config="plus1",
+        file_format=file_adapters.FileFormat.ARRAY_RECORD,
+    )
+    builder.download_and_prepare()
+
+    data_source = builder.as_data_source()
+    assert isinstance(data_source, dict)
+    assert isinstance(data_source["train"], array_record.ArrayRecordDataSource)
+    assert isinstance(data_source["test"], array_record.ArrayRecordDataSource)
+    assert len(data_source["test"]) == 10
+    assert data_source["test"][[0]][0]["x"] == 28
+    assert len(data_source["train"]) == 20
+    assert data_source["train"][[0]][0]["x"] == 7
+
+    data_source = builder.as_data_source(split="test")
+    assert isinstance(data_source, array_record.ArrayRecordDataSource)
+    assert len(data_source) == 10
+    assert data_source[[0]][0]["x"] == 28
+
 
 class DatasetBuilderMultiDirTest(testing.TestCase):
   """Tests for multi-dir."""
@@ -692,6 +716,56 @@ class BuilderPickleTest(testing.TestCase):
     self.assertEqual(builder.version, builder2.version)
 
 
+class BuilderRestoreGcsTest(testing.TestCase):
+
+  def setUp(self):
+    super(BuilderRestoreGcsTest, self).setUp()
+
+    def load_mnist_dataset_info(self):
+      mnist_info_path = os.path.join(
+          utils.tfds_path(),
+          "testing/test_data/dataset_info/mnist/3.0.1",
+      )
+      mnist_info_path = os.path.normpath(mnist_info_path)
+      self.read_from_directory(mnist_info_path)
+
+    patcher = mock.patch.object(
+        dataset_info.DatasetInfo,
+        "initialize_from_bucket",
+        new=load_mnist_dataset_info,
+    )
+    patcher.start()
+    self.patch_gcs = patcher
+    self.addCleanup(patcher.stop)
+
+  def test_stats_restored_from_gcs(self):
+    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
+      builder = testing.DummyMnist(data_dir=tmp_dir)
+      self.assertEqual(builder.info.splits["train"].num_examples, 20)
+
+  def test_stats_not_restored_gcs_overwritten(self):
+    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
+      # If split are different that the one restored, stats should be recomputed
+      builder = testing.DummyMnist(data_dir=tmp_dir)
+      self.assertEqual(builder.info.splits["train"].num_examples, 20)
+
+  def test_gcs_not_exists(self):
+    # By disabling the patch, and because DummyMnist is not on GCS, we can
+    # simulate a new dataset starting from scratch
+    self.patch_gcs.stop()
+    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
+      builder = testing.DummyMnist(data_dir=tmp_dir)
+      # No dataset_info restored, so stats are empty
+      self.assertEqual(builder.info.splits.total_num_examples, 0)
+
+      dl_config = download.DownloadConfig()
+      builder.download_and_prepare(download_config=dl_config)
+
+      # Statistics should have been recomputed
+      self.assertEqual(builder.info.splits["train"].num_examples, 20)
+    self.patch_gcs.start()
+
+
 class DatasetBuilderGenerateModeTest(testing.TestCase):
 
   @classmethod
