@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@ import functools
 import io
 import multiprocessing
 import os
-from typing import Any, Dict, Mapping, Optional, Tuple, Union
+from typing import Any, Dict, Mapping, Optional, Tuple, Type, Union
 
 from etils import epath
 import numpy as np
@@ -51,7 +51,7 @@ from tensorflow_datasets.core.utils.lazy_imports_utils import tensorflow as tf
 _IMAGE_ENCODING_FORMAT = "png"
 
 
-def _convert_to_np_dtype(dtype: str) -> np.dtype:
+def _convert_to_np_dtype(dtype: str) -> Type[np.generic]:
   """Returns the `np.dtype` scalar feature."""
   str2val = {
       "bool": np.bool_,
@@ -195,13 +195,22 @@ def _convert_value(hf_value: Any, feature: feature_lib.FeatureConnector) -> Any:
   elif isinstance(feature, feature_lib.Sequence):
     if isinstance(hf_value, list):
       return hf_value
+    elif hf_value is None:
+      return []
     else:
       return [hf_value]
   elif isinstance(feature, feature_lib.Audio):
-    is_audio_dict = isinstance(hf_value, dict) and "path" in hf_value
-    if is_audio_dict:
-      return hf_value["path"]
-    raise ValueError(f"{hf_value} should be a dict with a 'path' key")
+    assert isinstance(hf_value, dict), f"Audio {hf_value} should be a dict"
+    if "array" in hf_value:
+      sample_rate = feature.sample_rate
+      # Hugging Face uses float, TFDS uses integers.
+      return [int(s * sample_rate) for s in hf_value["array"]]
+    if "path" in hf_value:
+      path = epath.Path(hf_value["path"])
+      if path.exists():
+        return path
+    else:
+      raise ValueError(f"{hf_value} is not a valid audio feature.")
   elif isinstance(hf_value, lazy_imports_lib.lazy_imports.PIL_Image.Image):
     buffer = io.BytesIO()
     hf_value.save(fp=buffer, format=_IMAGE_ENCODING_FORMAT)
