@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,7 +38,8 @@ import json
 import os
 import posixpath
 import tempfile
-from typing import Any, Dict, Optional, Tuple, Union
+import time
+from typing import Any, Dict, Iterable, Optional, Tuple, Union
 
 from absl import logging
 from etils import epath
@@ -622,6 +623,7 @@ class DatasetInfo(object):
     # Update fields which are not defined in the code. This means that
     # the code will overwrite fields which are present in
     # dataset_info.json.
+    fields_taken_from_code = []
     for field_name, field in self.as_proto.DESCRIPTOR.fields_by_name.items():
       field_value = getattr(self._info_proto, field_name)
       field_value_restored = getattr(parsed_proto, field_name)
@@ -639,13 +641,7 @@ class DatasetInfo(object):
       # If field is defined in code, we ignore the value.
       if is_defined:
         if field_value != field_value_restored:
-          logging.info(
-              (
-                  "Field info.%s from disk and from code do not match. "
-                  "Keeping the one from code."
-              ),
-              field_name,
-          )
+          fields_taken_from_code.append(field_name)
         continue
       # If the field is also not defined in JSON file, we do nothing
       if not is_defined_in_restored:
@@ -656,9 +652,65 @@ class DatasetInfo(object):
       else:
         setattr(self._info_proto, field_name, field_value_restored)
 
+    if fields_taken_from_code:
+      logging.info(
+          (
+              "Fields info.[%s] from disk and from code do not match. "
+              "Keeping the one from code."
+          ),
+          ", ".join(fields_taken_from_code),
+      )
+
     # Mark as fully initialized.
     self._fully_initialized = True
 
+  def add_file_data_source_access(
+      self, path: Union[epath.PathLike, Iterable[epath.PathLike]]
+  ) -> None:
+    """Records that the given query was used to generate this dataset.
+
+    Arguments:
+      path: path or paths of files that were read. Can be a file pattern.
+        Multiple paths or patterns can be specified as a comma-separated string
+        or a list.
+    """
+    access_timestamp_ms = _now_in_milliseconds()
+    if isinstance(path, str) or isinstance(path, epath.Path):
+      path = os.fspath(path).split(",")
+    for p in path:
+      self._info_proto.data_source_accesses.append(
+          dataset_info_pb2.DataSourceAccess(
+              access_timestamp_ms=access_timestamp_ms,
+              file_system=dataset_info_pb2.FileSystem(path=os.fspath(p)),
+          )
+      )
+
+  def add_sql_data_source_access(self, sql_query: str) -> None:
+    """Records that the given query was used to generate this dataset."""
+    self._info_proto.data_source_accesses.append(
+        dataset_info_pb2.DataSourceAccess(
+            access_timestamp_ms=_now_in_milliseconds(),
+            sql_query=dataset_info_pb2.SqlQuery(sql_query=sql_query),
+        )
+    )
+
+  def add_tfds_data_source_access(
+      self, dataset_reference: naming.DatasetReference
+  ) -> None:
+    """Records that the given query was used to generate this dataset."""
+    self._info_proto.data_source_accesses.append(
+        dataset_info_pb2.DataSourceAccess(
+            access_timestamp_ms=_now_in_milliseconds(),
+            tfds_dataset=dataset_info_pb2.TfdsDatasetReference(
+                name=dataset_reference.dataset_name,
+                config=dataset_reference.config,
+                version=str(dataset_reference.version),
+                data_dir=dataset_reference.data_dir,
+                ds_namespace=dataset_reference.namespace,
+            ),
+        )
+    )
+
   def initialize_from_bucket(self) -> None:
     """Initialize DatasetInfo from GCS bucket info files."""
     # In order to support Colab, we use the HTTP GCS API to access the metadata
@@ -938,6 +990,10 @@ def _metadata_filepath(data_dir: epath.PathLike) -> epath.Path:
   return epath.Path(data_dir) / constants.METADATA_FILENAME
 
 
+def _now_in_milliseconds() -> int:
+  return time.time_ns() // 1000
+
+
 class MetadataDict(Metadata, dict):
   """A `tfds.core.Metadata` object that acts as a `dict`.
 
