@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -101,4 +101,6 @@ def _read_files(path: epath.Path) -> Dict[Text, Text]:
   for inode in path.iterdir():
     if inode.name in _METADATA_FILES:
       name2path[inode.name] = path.joinpath(inode.name)
-  return utils.tree.parallel_map(lambda f: f.read_text("utf-8"), name2path)
+  return utils.tree.parallel_map(
+      lambda f: f.read_text(encoding="utf-8"), name2path
+  )
