@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,7 +29,8 @@ class KaggleTest(testing.TestCase):
       with testing.tmp_dir() as tmp_dir:
         out_path = kaggle.download_kaggle_data('digit-recognizer', tmp_dir)
         self.assertEqual(
-            os.fspath(out_path), os.path.join(tmp_dir, 'digit-recognizer'))
+            os.fspath(out_path), os.path.join(tmp_dir, 'digit-recognizer')
+        )
         with tf.io.gfile.GFile(os.path.join(out_path, 'output.txt')) as f:
           self.assertEqual('digit-recognizer', f.read())
 
@@ -39,20 +40,23 @@ class KaggleTest(testing.TestCase):
         out_path = kaggle.download_kaggle_data('user/dataset', tmp_dir)
         self.assertIsInstance(out_path, os.PathLike)
         self.assertEqual(
-            os.fspath(out_path), os.path.join(tmp_dir, 'user_dataset'))
+            os.fspath(out_path), os.path.join(tmp_dir, 'user_dataset')
+        )
         with tf.io.gfile.GFile(os.path.join(out_path, 'output.txt')) as f:
           self.assertEqual('user/dataset', f.read())
 
   def test_competition_download_404(self):
     with testing.mock_kaggle_api(err_msg='404 - Not found'):
       with testing.tmp_dir() as tmp_dir:
-        with self.assertRaisesRegex(ValueError,
-                                    'Please ensure you have spelled the name'):
+        with self.assertRaisesRegex(
+            ValueError, 'Please ensure you have spelled the name'
+        ):
           kaggle.download_kaggle_data('digit-recognize', tmp_dir)
 
   def test_kaggle_type(self):
     self.assertEqual(
-        kaggle._get_kaggle_type('digit-recognizer'), 'competitions')
+        kaggle._get_kaggle_type('digit-recognizer'), 'competitions'
+    )
     self.assertEqual(kaggle._get_kaggle_type('author/dataset'), 'datasets')
 
 
