@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -123,6 +123,11 @@ class LazyImporter(object):
   def mwparserfromhell(cls):
     return _try_import("mwparserfromhell")
 
+  @utils.classproperty
+  @classmethod
+  def mwxml(cls):
+    return _try_import("mwxml")
+
   @utils.classproperty
   @classmethod
   def networkx(cls):
