@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,7 +33,7 @@ dataset and 11,788 images in the 2011 dataset.
 Annotations include bounding boxes, segmentation labels.
 """
 
-_URL = ("http://www.vision.caltech.edu/visipedia/CUB-200.html")
+_URL = "http://www.vision.caltech.edu/visipedia/CUB-200.html"
 _CITATION = """\
 @techreport{WelinderEtal2010,
 Author = {P. Welinder and S. Branson and T. Mita and C. Wah and F. Schroff and S. Belongie and P. Perona},
@@ -64,34 +64,27 @@ class CaltechBirds2010(tfds.core.GeneratorBasedBuilder):
     )
 
   def _info(self):
-
     return tfds.core.DatasetInfo(
         builder=self,
         description=_DESCRIPTION,
         features=tfds.features.FeaturesDict({
             # Images are of varying size
-            "image":
-                tfds.features.Image(),
-            "image/filename":
-                tfds.features.Text(),
-            "label":
-                tfds.features.ClassLabel(num_classes=200),
-            "label_name":
-                tfds.features.Text(),
-            "bbox":
-                tfds.features.BBoxFeature(),
-            "segmentation_mask":
-                tfds.features.Image(
-                    shape=(None, None, 1),
-                    use_colormap=True,
-                ),
+            "image": tfds.features.Image(),
+            "image/filename": tfds.features.Text(),
+            "label": tfds.features.ClassLabel(num_classes=200),
+            "label_name": tfds.features.Text(),
+            "bbox": tfds.features.BBoxFeature(),
+            "segmentation_mask": tfds.features.Image(
+                shape=(None, None, 1),
+                use_colormap=True,
+            ),
         }),
         supervised_keys=("image", "label"),
         homepage=_URL,
-        citation=_CITATION)
+        citation=_CITATION,
+    )
 
   def _split_generators(self, dl_manager):
-
     download_path = dl_manager.download([
         self._caltech_birds_info.split_url,
         self._caltech_birds_info.annotations_url,
@@ -99,7 +92,7 @@ class CaltechBirds2010(tfds.core.GeneratorBasedBuilder):
     ])
     extracted_path = dl_manager.download_and_extract([
         self._caltech_birds_info.split_url,
-        self._caltech_birds_info.annotations_url
+        self._caltech_birds_info.annotations_url,
     ])
 
     train_path = os.path.join(extracted_path[0], "lists/train.txt")
@@ -119,13 +112,15 @@ class CaltechBirds2010(tfds.core.GeneratorBasedBuilder):
       # Parsing the .mat files which have the image annotations
       with path.open(mode="rb") as f:
         mat = scipy.io.loadmat(
-            f, squeeze_me=True, variable_names=["bbox", "seg"])
+            f, squeeze_me=True, variable_names=["bbox", "seg"]
+        )
       key = path.name.split(".")[0]
       attributes[key].append(mat["bbox"])
       attributes[key].append(mat["seg"])
 
     with concurrent.futures.ThreadPoolExecutor(
-        max_workers=_WORKERS) as executor:
+        max_workers=_WORKERS
+    ) as executor:
       futures = []
       for root, _, fnames in tf.io.gfile.walk(extracted_path[1]):
         root = epath.Path(root)
@@ -144,14 +139,16 @@ class CaltechBirds2010(tfds.core.GeneratorBasedBuilder):
                 "archive": dl_manager.iter_archive(download_path[2]),
                 "file_names": train_list,
                 "annotations": attributes,
-            }),
+            },
+        ),
         tfds.core.SplitGenerator(
             name=tfds.Split.TEST,
             gen_kwargs={
                 "archive": dl_manager.iter_archive(download_path[2]),
                 "file_names": test_list,
                 "annotations": attributes,
-            }),
+            },
+        ),
     ]
 
   def _get_bounding_box_values(self, bbox_annotations, img_width, img_height):
@@ -202,29 +199,26 @@ class CaltechBirds2010(tfds.core.GeneratorBasedBuilder):
       file_name = matches[-1].split(".")[0]  # pytype: disable=attribute-error
       segmentation_mask = annotations[file_name][1]
       height, width = segmentation_mask.shape
-      bbox = self._get_bounding_box_values(annotations[file_name][0], width,
-                                           height)
+      bbox = self._get_bounding_box_values(
+          annotations[file_name][0], width, height
+      )
       return fname, {
-          "image":
-              fobj,
-          "image/filename":
-              fname,
-          "label":
-              label_key,
-          "label_name":
-              label_name,
-          "bbox":
-              tfds.features.BBox(
-                  ymin=min(bbox[0], 1.0),
-                  xmin=min(bbox[1], 1.0),
-                  ymax=min(bbox[2], 1.0),
-                  xmax=min(bbox[3], 1.0)),
-          "segmentation_mask":
-              segmentation_mask[:, :, np.newaxis],
+          "image": fobj,
+          "image/filename": fname,
+          "label": label_key,
+          "label_name": label_name,
+          "bbox": tfds.features.BBox(
+              ymin=min(bbox[0], 1.0),
+              xmin=min(bbox[1], 1.0),
+              ymax=min(bbox[2], 1.0),
+              xmax=min(bbox[3], 1.0),
+          ),
+          "segmentation_mask": segmentation_mask[:, :, np.newaxis],
       }
 
     with concurrent.futures.ThreadPoolExecutor(
-        max_workers=_WORKERS) as executor:
+        max_workers=_WORKERS
+    ) as executor:
       for example in executor.map(process_file, archive):
         if example:
           yield example
@@ -241,7 +235,7 @@ class CaltechBirds2011(CaltechBirds2010):
         name=self.name,
         images_url="https://drive.google.com/uc?export=download&id=1hbzc_P1FuxMkcabkgn9ZKinBwW683j45",
         split_url=None,
-        annotations_url="https://drive.google.com/uc?export=download&id=1EamOKGLoTuZdtcVYbHMWNpkn3iAVj8TP"
+        annotations_url="https://drive.google.com/uc?export=download&id=1EamOKGLoTuZdtcVYbHMWNpkn3iAVj8TP",
     )
 
   def _info(self):
@@ -259,30 +253,37 @@ class CaltechBirds2011(CaltechBirds2010):
         }),
         supervised_keys=("image", "label"),
         homepage=_URL,
-        citation=_CITATION)
+        citation=_CITATION,
+    )
 
   def _split_generators(self, dl_manager):
-    download_path = dl_manager.download([
-        self._caltech_birds_info.images_url,
-    ])
+    download_path = dl_manager.download(
+        [
+            self._caltech_birds_info.images_url,
+        ]
+    )
 
     extracted_path = dl_manager.download_and_extract([
         self._caltech_birds_info.images_url,
-        self._caltech_birds_info.annotations_url
+        self._caltech_birds_info.annotations_url,
     ])
 
-    image_names_path = os.path.join(extracted_path[0],
-                                    "CUB_200_2011/images.txt")
-    split_path = os.path.join(extracted_path[0],
-                              "CUB_200_2011/train_test_split.txt")
-    bbox_path = os.path.join(extracted_path[0],
-                             "CUB_200_2011/bounding_boxes.txt")
+    image_names_path = os.path.join(
+        extracted_path[0], "CUB_200_2011/images.txt"
+    )
+    split_path = os.path.join(
+        extracted_path[0], "CUB_200_2011/train_test_split.txt"
+    )
+    bbox_path = os.path.join(
+        extracted_path[0], "CUB_200_2011/bounding_boxes.txt"
+    )
 
     train_list, test_list = [], []
     attributes = collections.defaultdict(list)
 
     with tf.io.gfile.GFile(split_path) as f, tf.io.gfile.GFile(
-        image_names_path) as f1, tf.io.gfile.GFile(bbox_path) as f2:
+        image_names_path
+    ) as f1, tf.io.gfile.GFile(bbox_path) as f2:
       for line, line1, line2 in zip(f, f1, f2):
         img_idx, val = line.split()
         idx, img_name = line1.split()
@@ -298,11 +299,13 @@ class CaltechBirds2011(CaltechBirds2010):
     def process_file(root, fname):
       with tf.io.gfile.GFile(os.path.join(root, fname), "rb") as png_f:
         mask = tfds.core.lazy_imports.cv2.imdecode(
-            np.frombuffer(png_f.read(), dtype=np.uint8), flags=0)
+            np.frombuffer(png_f.read(), dtype=np.uint8), flags=0
+        )
       attributes[fname.split(".")[0]].append(mask)
 
     with concurrent.futures.ThreadPoolExecutor(
-        max_workers=_WORKERS) as executor:
+        max_workers=_WORKERS
+    ) as executor:
       futures = []
       for root, _, files in tf.io.gfile.walk(extracted_path[1]):
         for fname in files:
@@ -319,14 +322,16 @@ class CaltechBirds2011(CaltechBirds2010):
                 "archive": dl_manager.iter_archive(download_path[0]),
                 "file_names": train_list,
                 "annotations": attributes,
-            }),
+            },
+        ),
         tfds.core.SplitGenerator(
             name=tfds.Split.TEST,
             gen_kwargs={
                 "archive": dl_manager.iter_archive(download_path[0]),
                 "file_names": test_list,
                 "annotations": attributes,
-            }),
+            },
+        ),
     ]
 
   def _get_bounding_box_values(self, bbox_annotations, img_width, img_height):
@@ -343,8 +348,9 @@ class CaltechBirds2011(CaltechBirds2010):
     xmin = float(bbox_annotations[0]) / img_width
     ymin = float(bbox_annotations[1]) / img_height
     xmax = (float(bbox_annotations[0]) + float(bbox_annotations[2])) / img_width
-    ymax = (float(bbox_annotations[1]) +
-            float(bbox_annotations[3])) / img_height
+    ymax = (
+        float(bbox_annotations[1]) + float(bbox_annotations[3])
+    ) / img_height
 
     return ymin, xmin, ymax, xmax
 
@@ -352,12 +358,14 @@ class CaltechBirds2011(CaltechBirds2010):
 class CaltechBirdsInfo(
     collections.namedtuple(
         "_CaltechBirdsInfo",
-        ["name", "images_url", "split_url", "annotations_url"])):
+        ["name", "images_url", "split_url", "annotations_url"],
+    )
+):
   """Contains the information necessary to generate a Caltech Birds dataset.
 
-    Args:
-        name (str): name of dataset.
-        images_url (str): images URL.
-        split_url (str): train/test split file URL.
-        annotations_url (str): annotation folder URL.
+  Args:
+      name (str): name of dataset.
+      images_url (str): images URL.
+      split_url (str): train/test split file URL.
+      annotations_url (str): annotation folder URL.
   """
