@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -73,9 +73,10 @@ class YahooLTRCConfig(tfds.core.BuilderConfig):
 class YahooLTRC(tfds.core.GeneratorBasedBuilder):
   """DatasetBuilder for yahoo_ltrc dataset."""
 
-  VERSION = tfds.core.Version("1.0.0")
+  VERSION = tfds.core.Version("1.1.0")
   RELEASE_NOTES = {
       "1.0.0": "Initial release.",
+      "1.1.0": "Add query and document identifiers.",
   }
   # pytype: disable=wrong-keyword-args
   # pylint: disable=unexpected-keyword-arg
@@ -97,14 +98,18 @@ class YahooLTRC(tfds.core.GeneratorBasedBuilder):
     """Returns the dataset metadata."""
     encoding = tfds.features.Encoding.ZLIB
     features = {
-        "float_features":
-            tfds.features.Tensor(
-                shape=(None, self.builder_config.num_features),
-                dtype=np.float64,
-                encoding=encoding),
-        _LABEL_NAME:
-            tfds.features.Tensor(
-                shape=(None,), dtype=np.float64, encoding=encoding)
+        "float_features": tfds.features.Tensor(
+            shape=(None, self.builder_config.num_features),
+            dtype=np.float64,
+            encoding=encoding,
+        ),
+        _LABEL_NAME: tfds.features.Tensor(
+            shape=(None,), dtype=np.float64, encoding=encoding
+        ),
+        "query_id": tfds.features.Text(),
+        "doc_id": tfds.features.Tensor(
+            shape=(None,), dtype=np.int64, encoding=encoding
+        ),
     }
 
     return tfds.core.DatasetInfo(
@@ -128,14 +133,15 @@ class YahooLTRC(tfds.core.GeneratorBasedBuilder):
     }
 
     splits = {
-        "train":
-            self._generate_examples(path / f"{prefix}.train.txt",
-                                    feature_names),
-        "vali":
-            self._generate_examples(path / f"{prefix}.valid.txt",
-                                    feature_names),
-        "test":
-            self._generate_examples(path / f"{prefix}.test.txt", feature_names)
+        "train": self._generate_examples(
+            path / f"{prefix}.train.txt", feature_names
+        ),
+        "vali": self._generate_examples(
+            path / f"{prefix}.valid.txt", feature_names
+        ),
+        "test": self._generate_examples(
+            path / f"{prefix}.test.txt", feature_names
+        ),
     }
 
     return splits
@@ -144,4 +150,5 @@ class YahooLTRC(tfds.core.GeneratorBasedBuilder):
     """Yields examples."""
     with tf.io.gfile.GFile(path, "r") as f:
       yield from LibSVMRankingParser(
-          f, feature_names, _LABEL_NAME, combine_features=True)
+          f, feature_names, _LABEL_NAME, combine_features=True
+      )
