@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,29 +33,40 @@ try:
   tfds.core.utils.docs.doc_private = doc_controls.doc_private
   tfds.core.utils.docs.do_not_doc = doc_controls.do_not_generate_docs
   # Same as `do_not_doc`, but also applied to children
-  tfds.core.utils.docs.do_not_doc_inheritable = doc_controls.do_not_doc_inheritable
+  tfds.core.utils.docs.do_not_doc_inheritable = (
+      doc_controls.do_not_doc_inheritable
+  )
   # Document the parent, but not the children
-  tfds.core.utils.docs.do_not_doc_in_subclasses = doc_controls.do_not_doc_in_subclasses
+  tfds.core.utils.docs.do_not_doc_in_subclasses = (
+      doc_controls.do_not_doc_in_subclasses
+  )
 except AttributeError:
   logging.info("Could not set TensorFlow documentation decorators.")
 
 FLAGS = flags.FLAGS
 
-flags.DEFINE_string("output_dir", "/tmp/datasets_api",
-                    "Where to output the docs")
-flags.DEFINE_string("code_url_prefix",
-                    "https://github.com/tensorflow/datasets/tree/master/tensorflow_datasets/",
-                    "The url prefix for links to code.")
+flags.DEFINE_string(
+    "output_dir", "/tmp/datasets_api", "Where to output the docs"
+)
+flags.DEFINE_string(
+    "code_url_prefix",
+    "https://github.com/tensorflow/datasets/tree/master/tensorflow_datasets/",
+    "The url prefix for links to code.",
+)
 
-flags.DEFINE_bool("search_hints", True,
-                  "Include metadata search hints in the generated files")
+flags.DEFINE_bool(
+    "search_hints", True, "Include metadata search hints in the generated files"
+)
 
-flags.DEFINE_string("site_path", "datasets/api_docs/python",
-                    "Path prefix in the _toc.yaml")
+flags.DEFINE_string(
+    "site_path", "datasets/api_docs/python", "Path prefix in the _toc.yaml"
+)
 
 
 def execute(output_dir, code_url_prefix, search_hints, site_path):
   """Builds API docs for tensorflow_datasets."""
+  # Testing is lazily imported, so we first force its import.
+  testing.DummyDataset  # pylint: disable=pointless-statement
   # Internally, tfds.testing defaults to None. Fill it in here so that we get
   # documentation.
   tfds.testing = testing
@@ -65,14 +76,19 @@ def execute(output_dir, code_url_prefix, search_hints, site_path):
       base_dir=os.path.dirname(tfds.__file__),
       search_hints=search_hints,
       code_url_prefix=code_url_prefix,
-      site_path=site_path)
+      site_path=site_path,
+  )
 
   doc_generator.build(output_dir)
 
 
 def main(unused_argv):
-  execute(FLAGS.output_dir, FLAGS.code_url_prefix, FLAGS.search_hints,
-          FLAGS.site_path)
+  execute(
+      FLAGS.output_dir,
+      FLAGS.code_url_prefix,
+      FLAGS.search_hints,
+      FLAGS.site_path,
+  )
 
 
 if __name__ == "__main__":
