@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2022 The TensorFlow Datasets Authors.
+# Copyright 2023 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 
 """TFDS typing annotations."""
 
+from etils import epath
 from tensorflow_datasets.core import decode
 from tensorflow_datasets.core import splits
 from tensorflow_datasets.core.features import feature
@@ -24,6 +25,9 @@ from tensorflow_datasets.core.utils import type_utils
 from tensorflow_datasets.core.utils.type_utils import *  # pylint: disable=wildcard-import
 # pylint: enable=unused-import
 
+# Accept both `str` and `pathlib.Path`-like
+PathLike = epath.PathLike
+
 DecoderArg = decode.partial_decode.DecoderArg
 FeatureSpecs = decode.partial_decode.FeatureSpecs
 FeatureConnectorArg = feature.FeatureConnectorArg
@@ -33,5 +37,6 @@ __all__ = type_utils.__all__ + [
     'DecoderArg',
     'FeatureConnectorArg',
     'FeatureSpecs',
+    'PathLike',
     'SplitArg',
 ]
